#
# spec file for package raft
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2024 Andreas Stieger <Andreas.Stieger@gmx.de
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define raft_sover 0
Name:           raft
Version:        0.22.1
Release:        1.3
Summary:        Asynchronous C implementation of the Raft consensus protocol
License:        LGPL-3.0-only WITH LGPL-3.0-linking-exception
URL:            https://github.com/cowsql/raft
Source:         https://github.com/cowsql/raft/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libtool
BuildRequires:  pkgconfig >= 0.9.0
BuildRequires:  pkgconfig(liblz4) >= 1.7.1
BuildRequires:  pkgconfig(libuv) >= 1.18.0

%description
This library is a asynchronous C implementation of the Raft consensus protocol.
It implements the core Raft algorithm logic, and various drivers are provided
that implement actual network communication and persistent data storage.

The library supports asynchronous or non-blocking I/O engines (such as libuv and
io_uring), although it can be used in threaded or blocking contexts as well.

%package -n libraft%{raft_sover}
Summary:        Asynchronous C implementation of the Raft consensus protocol

%description -n libraft%{raft_sover}
This library is a asynchronous C implementation of the Raft consensus protocol.
It implements the core Raft algorithm logic, and various drivers are provided
that implement actual network communication and persistent data storage.

The library supports asynchronous or non-blocking I/O engines (such as libuv and
io_uring), although it can be used in threaded or blocking contexts as well.

This package contains the shared library.

%package devel
Summary:        Development files for %{name}
Requires:       libraft%{raft_sover} = %{version}

%description devel
This library is a asynchronous C implementation of the Raft consensus protocol.
It implements the core Raft algorithm logic, and various drivers are provided
that implement actual network communication and persistent data storage.

The library supports asynchronous or non-blocking I/O engines (such as libuv and
io_uring), although it can be used in threaded or blocking contexts as well.
This library is a fully asynchronous C implementation of the Raft consensus protocol.

This package contains the files necessary for developing and building applications
using the library.

%prep
%autosetup -p1

%build
autoreconf -fiv
%configure \
	--disable-static
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%check
%make_build check

%ldconfig_scriptlets -n libraft%{raft_sover}

%files devel
%license LICENSE
%doc AUTHORS README.md
%{_includedir}/raft.h
%dir %{_includedir}/raft
%{_includedir}/raft/fixture.h
%{_includedir}/raft/uv.h
%{_libdir}/libraft.so
%{_libdir}/pkgconfig/raft.pc

%files -n libraft%{raft_sover}
%license LICENSE
%{_libdir}/libraft.so.%{raft_sover}
%{_libdir}/libraft.so.%{raft_sover}.*

%changelog
* Sun Mar 31 2024 Andreas Stieger <andreas.stieger@gmx.de>
- raft 0.22.1:
  * fix usages of uninitialized memory
  * fix double-free of entries batch
  * updates to documentation and tests
* Tue Feb 20 2024 Andreas Stieger <andreas.stieger@gmx.de>
- raft 0.22.0 - new upstream https://github.com/cowsql/raft
  This version is is a drop-in replacement of canonical/raft up to
  0.18.0
- contains improvements to the raft implementation in the
  replication and leader election code, a legacy shim for the v1
  API (disabled), test improvements and developer visible changes
* Mon Feb 19 2024 Andreas Stieger <andreas.stieger@gmx.de>
- raft 0.18.1:
  * final release of this project, will be discontinued and
    incorporated into dqlite
  * developer visible changes and bug fixes
* Wed Oct 18 2023 Andreas Stieger <Andreas.Stieger@gmx.de>
- raft 0.18.0:
  * bug fixes and developer visible refactorings
* Fri Jan 20 2023 Andreas Stieger <andreas.stieger@gmx.de>
- raft 0.17.1:
  * not API compatible
  * Correct quorum calculation that determines when it's safe to
    apply a log entry
  * Ensuring that a "known good" configuration is always available
    to roll back to when a new configuration can't be committe
  * Fix potential crashes when a Raft state transition occurs
    during an asynchronous operation like writing to disk.
* Sun Dec  4 2022 Andreas Stieger <andreas.stieger@gmx.de>
- raft 0.16.0:
  * support for hostnames
  * bug fixes
* Mon Sep  5 2022 Andreas Stieger <andreas.stieger@gmx.de>
- raft 0.15.0:
  * raft_io version 2 introducing async_work
  * raft_fsm version introducing snapshot_async
  * disable failing test for libuv 1.44.2 and higher
* Tue Jul 12 2022 Andreas Stieger <andreas.stieger@gmx.de>
- raft 0.14.0:
  * Support for automated recovery of corrupt segments upon startup
  * Bug fixes and developer visible changes
* Tue Apr 19 2022 Andreas Stieger <andreas.stieger@gmx.de>
- raft 0.13.0:
  * move to raft_fsm v2 introducing snapshot_finalize
* Tue Feb  1 2022 Andreas Stieger <andreas.stieger@gmx.de>
- raft 0.11.3:
  * initial support for tracing
  * protocol bug fixes
* Sun Aug  8 2021 Andreas Stieger <andreas.stieger@gmx.de>
- raft 0.11.2:
  * set start_index correctly when no closed segments are present
  * uv_segment code correctnes fixes
  * replication: do not send snapshots to offline nodes
* Tue Jun 22 2021 Andreas Stieger <andreas.stieger@gmx.de>
- raft 0.11.1:
  * libuv implementation will use lz4 to compress snapshots
  * minor bug fixes
* Wed May  5 2021 Andreas Stieger <andreas.stieger@gmx.de>
- raft 0.10.1:
  * Add raft_set_initial_shapshot_timeout to API
* Sat Sep 12 2020 Andreas Stieger <andreas.stieger@gmx.de>
- raft 0.9.25:
  * Add APIs to configure timeouts when promoting a stand-by
  * Improve detection of the version of the ZFS kernel module
  * Honor endianness when decoding test FSM commands
* Mon Jul 27 2020 Andreas Stieger <andreas.stieger@gmx.de>
- raft 0.9.24:
  * updates to tests
* Fri Jul 10 2020 Andreas Stieger <andreas.stieger@gmx.de>
- raft 0.9.23:
  * Disable async for UBIFS
  * Reset vote when converting to candidate and starting a prevote round
  * use internal configuration APIs in uv module
* Wed Jun  3 2020 Andreas Stieger <andreas.stieger@gmx.de>
- raft 0.9.22:
  * various raft protocol fixes
* Wed May 13 2020 Andreas Stieger <andreas.stieger@gmx.de>
- raft 0.9.19:
  * New raft_aligned_free() API
  * Fix coverity findings/ and compiler warnings
* Tue Apr 28 2020 Andreas Stieger <andreas.stieger@gmx.de>
- raft 0.9.18:
  * ignore empty snapshot data files, and other bug fixes
* Fri Jan 31 2020 Andreas Stieger <andreas.stieger@gmx.de>
- raft 0.9.17:
  * Fix probing for fully async I/O on older kernels
  * Check if we are still followers after completing a disk write
* Mon Jan  6 2020 Andreas Stieger <andreas.stieger@gmx.de>
- raft 0.9.16:
  * no concise changelog available
  * license changed to LGPL 3.0 with a static linking exception
* Thu Nov  7 2019 Andreas Stieger <andreas.stieger@gmx.de>
- raft 0.9.9:
  * fix many compiler warning and drop unused flags
  * Support forcing re-configuration and other improvements
* Thu Sep 19 2019 Andreas Stieger <andreas.stieger@gmx.de>
- raft 0.9.6:
  * raft_watch API dropped
  * don't stop half-way when deleting old segments
* Fri Aug 30 2019 Andreas Stieger <andreas.stieger@gmx.de>
- raft 0.9.5, initial package
